# SAP for Me Super/Cloud Admin for Workspace Provisioning
### On this page
  * [Overview](https://help.sap.com/docs/leanix/ea/sap-for-me-super-cloud-admin-for-workspace-provisioning#overview)
  * [Typical Scenarios Where the Super/Cloud Admin Is Critical](https://help.sap.com/docs/leanix/ea/sap-for-me-super-cloud-admin-for-workspace-provisioning#typical-scenarios-where-the-super/cloud-admin-is-critical)
  * [Prepare for SAP LeanIX Workspace Provisioning](https://help.sap.com/docs/leanix/ea/sap-for-me-super-cloud-admin-for-workspace-provisioning#prepare-for-sap-leanix-workspace-provisioning)
  * [Related Resources](https://help.sap.com/docs/leanix/ea/sap-for-me-super-cloud-admin-for-workspace-provisioning#related-resources)


The cloud administrator acts as the main IT contact during SAP LeanIX workspace provisioning. They receive key onboarding and provisioning emails from SAP and are responsible for creating and managing additional S‑users for successful access.
